@@ -36,10 +36,10 @@ extern "C"
 #include "params.h"
 #include "model.h"
 #include "exp_sep.h"
-#include <math.h>
-#include <stdlib.h>
-#include <assert.h>
-#include <string.h>
+#include <cmath>
+#include <cstdlib>
+#include <cassert>
+#include <cstring>
 #include <string>
 #include <fstream>
 using namespace std;
