@@ -22,6 +22,7 @@
  ********************************************************************************/
 
 
+#include <R_ext/Error.h>
 extern "C"
 {
 #include "matrix.h"
@@ -33,12 +34,12 @@ extern "C"
 #include "model.h"
 #include "params.h"
 #include "mstructs.h"
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #include <fstream>
-#include <time.h>
-#include <math.h>
+#include <ctime>
+#include <cmath>
 
 extern "C"
 {
@@ -70,7 +71,7 @@ void tgp(int* state_in,
 {
 
   /* create the RNG state */
-  unsigned int lstate = three2lstate(state_in);
+  unsigned long lstate = three2lstate(state_in);
   tgp_state = newRNGstate(lstate);
 
   /* possibly create NULL pointers that couldn't be passed by .C -- not sure if all are needed */
@@ -392,7 +393,7 @@ void Tgp::Rounds(void)
 void Tgp::Predict(void)
 {
   /* don't need multiple rounds R when just kriging */
-  if(R > 1) warning("R=%d (>0) not necessary for Kriging", R);
+  if(R > 1) Rf_warning("R=%d (>0) not necessary for Kriging", R);
 
   for(unsigned int i=0; i<R; i++) {
 
